import { Template } from "../../store/useTemplateStore";
import { captureVisualization } from "./captureVisualization";

type HandleSaveTemplateProps = {
    addTemplate: (template: Template) => void;
    selectedZone: {
        panelOrder: string[]; // Adjust the type based on actual data structure
        widgets: any[]; // Replace `any` with the actual widget type
    };
};

// Generate a unique ID (placeholder function)
const generateUniqueId = (): string => {
    return Math.random().toString(36).substring(2, 15);
};

// Refactored function
export const handleSaveTemplate = async ({
    addTemplate,
    selectedZone,
}: HandleSaveTemplateProps): Promise<void> => {
    try {
        const snapshot = await captureVisualization();
        const template: Template = {
            id: generateUniqueId(),
            name: `Template ${Date.now()}`,
            panelOrder: selectedZone.panelOrder,
            widgets: selectedZone.widgets,
            snapshot,
        };
        console.log('template: ', template);
        addTemplate(template);
    } catch (error) {
        console.error('Failed to save template:', error);
    }
};
